@@ -13,7 +13,8 @@ D<-as.vector(family$mu.eta(Eta))
 W0_inv<-D*1/Sigma*D
 
 if(print.iter.final)
-print(paste("Final Re-estimation Iteration ", 1,sep=""))
+  message("Final Re-estimation Iteration ", 1)
+#print(paste("Final Re-estimation Iteration ", 1,sep=""))
 
 
 Z_alles<-cbind(X,W)
@@ -49,7 +50,7 @@ Q[[1]]<-q_start
 l=1
 opt<-steps
 
-score_vec<-t(Z_alles)%*%((y-Mu)*D*1/Sigma)#-P1%*%Delta[1,]
+score_vec<-t(Z_alles)%*%((y-Mu)*D*1/Sigma)-P1%*%Delta[1,]
 F_gross<-t(Z_alles)%*%(Z_alles*D*1/Sigma*D)+P1
 
 InvFisher<-try(chol2inv(chol(F_gross)),silent=TRUE)
@@ -191,7 +192,7 @@ if(all(s==1))
   }
 }
 
-score_vec<-t(Z_alles)%*%((y-Mu)*D*1/Sigma)#-P1%*%Delta[1,]
+score_vec<-t(Z_alles)%*%((y-Mu)*D*1/Sigma)-P1%*%Delta[1,]
 F_gross<-t(Z_alles)%*%(Z_alles*D*1/Sigma*D)+P1
 
 InvFisher<-try(chol2inv(chol(F_gross)),silent=TRUE)
@@ -223,7 +224,8 @@ for (l in 2:steps)
 {
   
 if(print.iter.final)
-print(paste("Final Re-estimation Iteration ", l,sep=""))
+  message("Final Re-estimation Iteration ", l)
+#print(paste("Final Re-estimation Iteration ", l,sep=""))
 
 half.index<-0
 solve.test<-FALSE
@@ -371,7 +373,7 @@ if(all(s==1))
   }
 }
 
-score_vec<-t(Z_alles)%*%((y-Mu)*D*1/Sigma)#-P1%*%Delta[l-1,]
+score_vec<-t(Z_alles)%*%((y-Mu)*D*1/Sigma)-P1%*%Delta[l-1,]
 F_gross<-t(Z_alles)%*%(Z_alles*D*1/Sigma*D)+P1
 
   InvFisher<-try(chol2inv(chol(F_gross)),silent=TRUE)
